@@ -1,5 +1,6 @@
 package Flickr::API2::Photos;
 use Mouse;
+use Flickr::API2::Photo;
 extends 'Flickr::API2::Base';
 
 =head1 NAME
@@ -8,10 +9,31 @@ Flickr::API2::Photos
 
 =head1 SYNOPSIS
 
-See search() below.
+See search() and by_id() methods below.
 
 =head1 METHODS
 
+=head2 by_id
+
+Finds one photo by its id number.
+
+eg. say $api->photos->by_id(3386874895)->title;
+
+=cut
+
+sub by_id {
+    my ($self, $id) = @_;
+    my $p = Flickr::API2::Photo->new( api => $self->api, id => $id );
+    my $info = $p->info->{photo};
+    $p->title($info->{title}{_content});
+    $p->description($info->{description}{_content});
+    $p->owner_name($info->{owner}{realname});
+    $p->owner_id($info->{owner}{nsid});
+    $p->path_alias($info->{owner}{username});
+
+    return $p;
+}
+
 =head2 search
 
 Search for photos, for eg:
